#!/bin/bash
gmt gmtset PS_MEDIA letter
gmt gmtset PROJ_LENGTH_UNIT cm
gmt gmtset FORMAT_GEO_MAP D
gmt gmtset PS_PAGE_ORIENTATION portrait
psfile=longnan2.21_base.ps
projection=-JM16.0c+
region=-R102.4/105.5/32.1/34.4
gmt psbasemap $region $projection -Bxa1.0f0.1 -Bya1.0f0.1 -BWeSn+t'Base Map longnan2.21' -K > $psfile

# Standard Topography (ETOPO1)
palette=-Ctables/gmt/cpt/topo.cpt
gmt grdcut @earth_relief_01m_g -Gmloc.grd $region
gmt grdgradient mloc.grd -Gmloc_ilum.grd -A340 -Nt
gmt grdimage mloc.grd $palette $projection -Imloc_ilum.grd -O -K >> $psfile
rm mloc.grd mloc_ilum.grd

# Coastlines and rivers
gmt pscoast $projection $region -Df -Ia/blue -Wblue -O -K >> $psfile

# Event numbers
gmt psxy -: -R $projection -Sl8p+t"1" -G0 -O -K << END >> $psfile
    32.892   103.934
END
gmt psxy -: -R $projection -Sl8p+t"2" -G0 -O -K << END >> $psfile
    32.877   103.959
END
gmt psxy -: -R $projection -Sl8p+t"3" -G0 -O -K << END >> $psfile
    32.899   103.963
END
gmt psxy -: -R $projection -Sl8p+t"4" -G0 -O -K << END >> $psfile
    32.922   104.017
END
gmt psxy -: -R $projection -Sl8p+t"5" -G0 -O -K << END >> $psfile
    32.898   103.974
END
gmt psxy -: -R $projection -Sl8p+t"6" -G0 -O -K << END >> $psfile
    32.886   103.905
END
gmt psxy -: -R $projection -Sl8p+t"7" -G0 -O -K << END >> $psfile
    32.862   103.928
END
gmt psxy -: -R $projection -Sl8p+t"8" -G0 -O -K << END >> $psfile
    32.895   103.937
END
gmt psxy -: -R $projection -Sl8p+t"9" -G0 -O -K << END >> $psfile
    32.911   103.957
END
gmt psxy -: -R $projection -Sl8p+t"10" -G0 -O -K << END >> $psfile
    32.872   103.906
END
gmt psxy -: -R $projection -Sl8p+t"11" -G0 -O -K << END >> $psfile
    32.998   103.945
END
gmt psxy -: -R $projection -Sl8p+t"12" -G0 -O -K << END >> $psfile
    32.904   103.941
END
gmt psxy -: -R $projection -Sl8p+t"13" -G0 -O -K << END >> $psfile
    32.882   103.892
END
gmt psxy -: -R $projection -Sl8p+t"14" -G0 -O -K << END >> $psfile
    32.899   104.027
END
gmt psxy -: -R $projection -Sl8p+t"15" -G0 -O -K << END >> $psfile
    32.939   104.031
END
gmt psxy -: -R $projection -Sl8p+t"16" -G0 -O -K << END >> $psfile
    32.996   104.071
END
gmt psxy -: -R $projection -Sl8p+t"17" -G0 -O -K << END >> $psfile
    33.027   103.930
END
gmt psxy -: -R $projection -Sl8p+t"18" -G0 -O -K << END >> $psfile
    32.719   104.044
END
gmt psxy -: -R $projection -Sl8p+t"19" -G0 -O -K << END >> $psfile
    32.637   104.170
END
gmt psxy -: -R $projection -Sl8p+t"20" -G0 -O -K << END >> $psfile
    32.793   104.078
END
gmt psxy -: -R $projection -Sl8p+t"21" -G0 -O -K << END >> $psfile
    32.862   104.122
END
gmt psxy -: -R $projection -Sl8p+t"22" -G0 -O -K << END >> $psfile
    32.588   104.177
END
gmt psxy -: -R $projection -Sl8p+t"23" -G0 -O -K << END >> $psfile
    32.749   104.101
END
gmt psxy -: -R $projection -Sl8p+t"24" -G0 -O -K << END >> $psfile
    32.460   104.107
END
gmt psxy -: -R $projection -Sl8p+t"25" -G0 -O -K << END >> $psfile
    32.358   104.141
END
gmt psxy -: -R $projection -Sl8p+t"26" -G0 -O -K << END >> $psfile
    32.472   104.066
END
gmt psxy -: -R $projection -Sl8p+t"27" -G0 -O -K << END >> $psfile
    32.823   104.071
END
gmt psxy -: -R $projection -Sl8p+t"28" -G0 -O -K << END >> $psfile
    32.915   104.097
END
gmt psxy -: -R $projection -Sl8p+t"29" -G0 -O -K << END >> $psfile
    32.643   104.144
END
gmt psxy -: -R $projection -Sl8p+t"30" -G0 -O -K << END >> $psfile
    32.827   104.147
END
gmt psxy -: -R $projection -Sl8p+t"31" -G0 -O -K << END >> $psfile
    34.097   104.404
END
gmt psxy -: -R $projection -Sl8p+t"32" -G0 -O -K << END >> $psfile
    33.410   104.778
END
gmt psxy -: -R $projection -Sl8p+t"33" -G0 -O -K << END >> $psfile
    32.615   104.161
END
gmt psxy -: -R $projection -Sl8p+t"34" -G0 -O -K << END >> $psfile
    33.064   104.927
END
gmt psxy -: -R $projection -Sl8p+t"35" -G0 -O -K << END >> $psfile
    34.025   104.308
END
gmt psxy -: -R $projection -Sl8p+t"36" -G0 -O -K << END >> $psfile
    32.448   104.195
END
gmt psxy -: -R $projection -Sl8p+t"37" -G0 -O -K << END >> $psfile
    32.927   103.989
END
gmt psxy -: -R $projection -Sl8p+t"38" -G0 -O -K << END >> $psfile
    32.977   104.027
END
gmt psxy -: -R $projection -Sl8p+t"39" -G0 -O -K << END >> $psfile
    32.733   104.093
END
gmt psxy -: -R $projection -Sl8p+t"40" -G0 -O -K << END >> $psfile
    32.579   103.434
END
gmt psxy -: -R $projection -Sl8p+t"41" -G0 -O -K << END >> $psfile
    32.868   104.091
END
gmt psxy -: -R $projection -Sl8p+t"42" -G0 -O -K << END >> $psfile
    33.336   104.409
END
gmt psxy -: -R $projection -Sl8p+t"43" -G0 -O -K << END >> $psfile
    33.386   103.243
END
gmt psxy -: -R $projection -Sl8p+t"44" -G0 -O -K << END >> $psfile
    32.391   104.215
END
gmt psxy -: -R $projection -Sl8p+t"45" -G0 -O -K << END >> $psfile
    34.256   103.297
END
gmt psxy -: -R $projection -Sl8p+t"46" -G0 -O -K << END >> $psfile
    34.261   103.315
END
gmt psxy -: -R $projection -Sl8p+t"47" -G0 -O -K << END >> $psfile
    34.307   103.319
END
gmt psxy -: -R $projection -Sl8p+t"48" -G0 -O -K << END >> $psfile
    33.594   103.688
END
gmt psxy -: -R $projection -Sl8p+t"49" -G0 -O -K << END >> $psfile
    32.819   104.097
END
gmt psxy -: -R $projection -Sl8p+t"50" -G0 -O -K << END >> $psfile
    32.818   104.106
END
gmt psxy -: -R $projection -Sl8p+t"51" -G0 -O -K << END >> $psfile
    34.082   105.101
END
gmt psxy -: -R $projection -Sl8p+t"52" -G0 -O -K << END >> $psfile
    34.289   103.303
END
gmt psxy -: -R $projection -Sl8p+t"53" -G0 -O -K << END >> $psfile
    32.453   104.116
END
gmt psxy -: -R $projection -Sl8p+t"54" -G0 -O -K << END >> $psfile
    32.950   103.882
END
gmt psxy -: -R $projection -Sl8p+t"55" -G0 -O -K << END >> $psfile
    33.110   104.846
END
gmt psxy -: -R $projection -Sl8p+t"56" -G0 -O -K << END >> $psfile
    32.228   103.719
END
gmt psxy -: -R $projection -Sl8p+t"57" -G0 -O -K << END >> $psfile
    32.967   103.964
END
gmt psxy -: -R $projection -Sl8p+t"58" -G0 -O -K << END >> $psfile
    33.728   104.795
END
gmt psxy -: -R $projection -Sl8p+t"59" -G0 -O -K << END >> $psfile
    33.428   103.822
END
gmt psxy -: -R $projection -Sl8p+t"60" -G0 -O -K << END >> $psfile
    33.039   104.516
END
gmt psxy -: -R $projection -Sl8p+t"61" -G0 -O -K << END >> $psfile
    33.010   104.492
END
gmt psxy -: -R $projection -Sl8p+t"62" -G0 -O -K << END >> $psfile
    33.126   103.830
END
gmt psxy -: -R $projection -Sl8p+t"63" -G0 -O -K << END >> $psfile
    33.117   103.803
END
gmt psxy -: -R $projection -Sl8p+t"64" -G0 -O -K << END >> $psfile
    33.336   103.796
END
gmt psxy -: -R $projection -Sl8p+t"65" -G0 -O -K << END >> $psfile
    32.596   104.197
END
gmt psxy -: -R $projection -Sl8p+t"66" -G0 -O -K << END >> $psfile
    33.890   102.807
END
gmt psxy -: -R $projection -Sl8p+t"67" -G0 -O -K << END >> $psfile
    33.121   103.824
END
gmt psxy -: -R $projection -Sl8p+t"68" -G0 -O -K << END >> $psfile
    33.116   103.817
END
gmt psxy -: -R $projection -Sl8p+t"69" -G0 -O -K << END >> $psfile
    33.709   103.276
END
gmt psxy -: -R $projection -Sl8p+t"70" -G0 -O -K << END >> $psfile
    33.019   103.863
END
gmt psxy -: -R $projection -Sl8p+t"71" -G0 -O -K << END >> $psfile
    33.130   103.657
END
gmt psxy -: -R $projection -Sl8p+t"72" -G0 -O -K << END >> $psfile
    33.323   104.635
END
gmt psxy -: -R $projection -Sl8p+t"73" -G0 -O -K << END >> $psfile
    32.505   104.031
END
gmt psxy -: -R $projection -Sl8p+t"74" -G0 -O -K << END >> $psfile
    32.970   103.970
END
gmt psxy -: -R $projection -Sl8p+t"75" -G0 -O -K << END >> $psfile
    33.393   102.779
END
gmt psxy -: -R $projection -Sl8p+t"76" -G0 -O -K << END >> $psfile
    33.122   103.835
END
gmt psxy -: -R $projection -Sl8p+t"77" -G0 -O -K << END >> $psfile
    34.150   102.835
END
gmt psxy -: -R $projection -Sl8p+t"78" -G0 -O -K << END >> $psfile
    32.601   103.328
END
gmt psxy -: -R $projection -Sl8p+t"79" -G0 -O -K << END >> $psfile
    33.244   103.849
END
gmt psxy -: -R $projection -Sl8p+t"80" -G0 -O -K << END >> $psfile
    33.246   103.830
END
gmt psxy -: -R $projection -Sl8p+t"81" -G0 -O -K << END >> $psfile
    33.799   103.987
END
gmt psxy -: -R $projection -Sl8p+t"82" -G0 -O -K << END >> $psfile
    32.989   102.646
END
gmt psxy -: -R $projection -Sl8p+t"83" -G0 -O -K << END >> $psfile
    32.271   104.429
END
gmt psxy -: -R $projection -Sl8p+t"84" -G0 -O -K << END >> $psfile
    32.241   104.536
END
gmt psxy -: -R $projection -Sl8p+t"85" -G0 -O -K << END >> $psfile
    33.864   103.887
END
gmt psxy -: -R $projection -Sl8p+t"86" -G0 -O -K << END >> $psfile
    33.613   104.828
END
gmt psxy -: -R $projection -Sl8p+t"87" -G0 -O -K << END >> $psfile
    32.647   102.515
END
gmt psxy -: -R $projection -Sl8p+t"88" -G0 -O -K << END >> $psfile
    32.617   102.503
END
gmt psxy -: -R $projection -Sl8p+t"89" -G0 -O -K << END >> $psfile
    33.312   103.467
END
gmt psxy -: -R $projection -Sl8p+t"90" -G0 -O -K << END >> $psfile
    32.937   104.533
END
gmt psxy -: -R $projection -Sl8p+t"91" -G0 -O -K << END >> $psfile
    34.320   103.325
END
gmt psxy -: -R $projection -Sl8p+t"92" -G0 -O -K << END >> $psfile
    33.218   103.146
END
gmt psxy -: -R $projection -Sl8p+t"93" -G0 -O -K << END >> $psfile
    32.744   102.813
END
gmt psxy -: -R $projection -Sl8p+t"94" -G0 -O -K << END >> $psfile
    32.641   103.024
END
gmt psxy -: -R $projection -Sl8p+t"95" -G0 -O -K << END >> $psfile
    32.243   103.705
END
gmt psxy -: -R $projection -Sl8p+t"96" -G0 -O -K << END >> $psfile
    33.663   102.787
END
gmt psxy -: -R $projection -Sl8p+t"97" -G0 -O -K << END >> $psfile
    34.300   103.275
END
gmt psxy -: -R $projection -Sl8p+t"98" -G0 -O -K << END >> $psfile
    32.277   104.657
END
gmt psxy -: -R $projection -Sl8p+t"99" -G0 -O -K << END >> $psfile
    33.587   104.508
END
gmt psxy -: -R $projection -Sl8p+t"100" -G0 -O -K << END >> $psfile
    32.782   104.174
END
gmt psxy -: -R $projection -Sl8p+t"101" -G0 -O -K << END >> $psfile
    33.319   103.434
END
gmt psxy -: -R $projection -Sl8p+t"102" -G0 -O -K << END >> $psfile
    32.628   102.581
END
gmt psxy -: -R $projection -Sl8p+t"103" -G0 -O -K << END >> $psfile
    32.239   103.760
END
gmt psxy -: -R $projection -Sl8p+t"104" -G0 -O -K << END >> $psfile
    33.124   104.912
END
gmt psxy -: -R $projection -Sl8p+t"105" -G0 -O -K << END >> $psfile
    32.656   104.133
END
gmt psxy -: -R $projection -Sl8p+t"106" -G0 -O -K << END >> $psfile
    33.398   104.705
END
gmt psxy -: -R $projection -Sl8p+t"107" -G0 -O -K << END >> $psfile
    33.098   104.946
END
gmt psxy -: -R $projection -Sl8p+t"108" -G0 -O -K << END >> $psfile
    33.368   104.753
END
gmt psxy -: -R $projection -Sl8p+t"109" -G0 -O -K << END >> $psfile
    33.108   104.568
END
gmt psxy -: -R $projection -Sl8p+t"110" -G0 -O -K << END >> $psfile
    32.744   104.788
END
gmt psxy -: -R $projection -Sl8p+t"111" -G0 -O -K << END >> $psfile
    32.952   104.214
END
gmt psxy -: -R $projection -Sl8p+t"112" -G0 -O -K << END >> $psfile
    33.088   104.893
END
gmt psxy -: -R $projection -Sl8p+t"113" -G0 -O -K << END >> $psfile
    33.074   102.656
END
gmt psxy -: -R $projection -Sl8p+t"114" -G0 -O -K << END >> $psfile
    34.300   104.848
END
gmt psxy -: -R $projection -Sl8p+t"115" -G0 -O -K << END >> $psfile
    33.666   104.908
END
gmt psxy -: -R $projection -Sl8p+t"116" -G0 -O -K << END >> $psfile
    33.833   104.910
END
gmt psxy -: -R $projection -Sl8p+t"117" -G0 -O -K << END >> $psfile
    34.075   104.341
END
gmt psxy -: -R $projection -Sl8p+t"118" -G0 -O -K << END >> $psfile
    33.927   104.366
END
gmt psxy -: -R $projection -Sl8p+t"119" -G0 -O -K << END >> $psfile
    33.061   104.791
END
gmt psxy -: -R $projection -Sl8p+t"120" -G0 -O -K << END >> $psfile
    32.199   104.859
END
gmt psxy -: -R $projection -Sl8p+t"121" -G0 -O -K << END >> $psfile
    32.323   105.171
END
gmt psxy -: -R $projection -Sl8p+t"122" -G0 -O -K << END >> $psfile
    32.248   104.894
END
gmt psxy -: -R $projection -Sl8p+t"123" -G0 -O -K << END >> $psfile
    32.300   104.881
END
gmt psxy -: -R $projection -Sl8p+t"124" -G0 -O -K << END >> $psfile
    32.565   105.297
END
gmt psxy -: -R $projection -Sl8p+t"125" -G0 -O -K << END >> $psfile
    32.290   104.976
END
gmt psxy -: -R $projection -Sl8p+t"126" -G0 -O -K << END >> $psfile
    32.529   105.168
END
gmt psxy -: -R $projection -Sl8p+t"127" -G0 -O -K << END >> $psfile
    32.418   104.994
END
gmt psxy -: -R $projection -Sl8p+t"128" -G0 -O -K << END >> $psfile
    32.485   105.057
END
gmt psxy -: -R $projection -Sl8p+t"129" -G0 -O -K << END >> $psfile
    32.348   105.032
END
gmt psxy -: -R $projection -Sl8p+t"130" -G0 -O -K << END >> $psfile
    32.265   104.889
END
gmt psxy -: -R $projection -Sl8p+t"131" -G0 -O -K << END >> $psfile
    32.506   105.213
END
gmt psxy -: -R $projection -Sl8p+t"132" -G0 -O -K << END >> $psfile
    32.302   104.976
END
gmt psxy -: -R $projection -Sl8p+t"133" -G0 -O -K << END >> $psfile
    32.456   105.104
END
gmt psxy -: -R $projection -Sl8p+t"134" -G0 -O -K << END >> $psfile
    32.260   104.606
END
gmt psxy -: -R $projection -Sl8p+t"135" -G0 -O -K << END >> $psfile
    32.454   105.077
END
gmt psxy -: -R $projection -Sl8p+t"136" -G0 -O -K << END >> $psfile
    32.251   104.762
END
gmt psxy -: -R $projection -Sl8p+t"137" -G0 -O -K << END >> $psfile
    32.211   104.829
END
gmt psxy -: -R $projection -Sl8p+t"138" -G0 -O -K << END >> $psfile
    32.423   105.234
END
gmt psxy -: -R $projection -Sl8p+t"139" -G0 -O -K << END >> $psfile
    32.234   104.858
END
gmt psxy -: -R $projection -Sl8p+t"140" -G0 -O -K << END >> $psfile
    32.399   105.047
END
gmt psxy -: -R $projection -Sl8p+t"141" -G0 -O -K << END >> $psfile
    32.345   104.848
END
gmt psxy -: -R $projection -Sl8p+t"142" -G0 -O -K << END >> $psfile
    32.546   105.293
END
gmt psxy -: -R $projection -Sl8p+t"143" -G0 -O -K << END >> $psfile
    32.509   105.096
END
gmt psxy -: -R $projection -Sl8p+t"144" -G0 -O -K << END >> $psfile
    32.639   105.321
END
gmt psxy -: -R $projection -Sl8p+t"145" -G0 -O -K << END >> $psfile
    32.671   105.311
END
gmt psxy -: -R $projection -Sl8p+t"146" -G0 -O -K << END >> $psfile
    32.325   104.937
END
gmt psxy -: -R $projection -Sl8p+t"147" -G0 -O -K << END >> $psfile
    32.289   105.014
END
gmt psxy -: -R $projection -Sl8p+t"148" -G0 -O -K << END >> $psfile
    32.321   104.910
END
gmt psxy -: -R $projection -Sl8p+t"149" -G0 -O -K << END >> $psfile
    32.532   105.314
END
gmt psxy -: -R $projection -Sl8p+t"150" -G0 -O -K << END >> $psfile
    32.480   104.986
END
gmt psxy -: -R $projection -Sl8p+t"151" -G0 -O -K << END >> $psfile
    32.496   105.069
END
gmt psxy -: -R $projection -Sl8p+t"152" -G0 -O -K << END >> $psfile
    32.292   104.805
END
gmt psxy -: -R $projection -Sl8p+t"153" -G0 -O -K << END >> $psfile
    32.408   105.086
END
gmt psxy -: -R $projection -Sl8p+t"154" -G0 -O -K << END >> $psfile
    32.372   105.026
END
gmt psxy -: -R $projection -Sl8p+t"155" -G0 -O -K << END >> $psfile
    32.471   105.147
END
gmt psxy -: -R $projection -Sl8p+t"156" -G0 -O -K << END >> $psfile
    32.511   105.275
END
gmt psxy -: -R $projection -Sl8p+t"157" -G0 -O -K << END >> $psfile
    32.286   104.974
END
gmt psxy -: -R $projection -Sl8p+t"158" -G0 -O -K << END >> $psfile
    32.397   104.989
END
gmt psxy -: -R $projection -Sl8p+t"159" -G0 -O -K << END >> $psfile
    32.212   104.792
END
gmt psxy -: -R $projection -Sl8p+t"160" -G0 -O -K << END >> $psfile
    32.529   105.089
END
gmt psxy -: -R $projection -Sl8p+t"161" -G0 -O -K << END >> $psfile
    32.300   104.783
END
gmt psxy -: -R $projection -Sl8p+t"162" -G0 -O -K << END >> $psfile
    32.505   105.135
END
gmt psxy -: -R $projection -Sl8p+t"163" -G0 -O -K << END >> $psfile
    32.203   104.391
END
gmt psxy -: -R $projection -Sl8p+t"164" -G0 -O -K << END >> $psfile
    32.514   105.331
END
gmt psxy -: -R $projection -Sl8p+t"165" -G0 -O -K << END >> $psfile
    32.509   105.192
END
gmt psxy -: -R $projection -Sl8p+t"166" -G0 -O -K << END >> $psfile
    32.456   105.063
END
gmt psxy -: -R $projection -Sl8p+t"167" -G0 -O -K << END >> $psfile
    32.959   104.828
END
gmt psxy -: -R $projection -Sl8p+t"168" -G0 -O -K << END >> $psfile
    32.498   105.076
END
gmt psxy -: -R $projection -Sl8p+t"169" -G0 -O -K << END >> $psfile
    32.211   104.448
END
gmt psxy -: -R $projection -Sl8p+t"170" -G0 -O -K << END >> $psfile
    32.291   105.412
END
gmt psxy -: -R $projection -Sl8p+t"171" -G0 -O -K << END >> $psfile
    33.200   103.712
END
gmt psxy -: -R $projection -Sl8p+t"172" -G0 -O -K << END >> $psfile
    33.156   103.729
END
gmt psxy -: -R $projection -Sl8p+t"173" -G0 -O -K << END >> $psfile
    33.230   103.748
END
gmt psxy -: -R $projection -Sl8p+t"174" -G0 -O -K << END >> $psfile
    33.155   103.567
END
gmt psxy -: -R $projection -Sl8p+t"175" -G0 -O -K << END >> $psfile
    33.622   102.864
END

# Change in location, calibration shift if available
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.894   103.933
    32.892   103.934
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.867   104.007
    32.892   103.934
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.880   103.959
    32.877   103.959
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.838   104.054
    32.877   103.959
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.899   103.967
    32.899   103.963
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.900   104.100
    32.899   103.963
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.924   104.011
    32.922   104.017
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    33.000   104.100
    32.922   104.017
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.899   103.973
    32.898   103.974
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.900   104.100
    32.898   103.974
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.886   103.909
    32.886   103.905
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.900   104.100
    32.886   103.905
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.865   103.923
    32.862   103.928
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.900   104.100
    32.862   103.928
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.903   103.931
    32.895   103.937
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    33.000   103.900
    32.895   103.937
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.916   103.956
    32.911   103.957
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.900   104.200
    32.911   103.957
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.876   103.900
    32.872   103.906
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.900   103.900
    32.872   103.906
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    33.002   103.946
    32.998   103.945
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    33.000   103.900
    32.998   103.945
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.904   103.938
    32.904   103.941
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.900   104.100
    32.904   103.941
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.884   103.890
    32.882   103.892
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.625   103.789
    32.882   103.892
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.899   104.034
    32.899   104.027
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.902   103.986
    32.899   104.027
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.941   104.030
    32.939   104.031
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    33.014   104.125
    32.939   104.031
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.997   104.068
    32.996   104.071
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    33.000   104.000
    32.996   104.071
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    33.029   103.926
    33.027   103.930
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    33.057   104.086
    33.027   103.930
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.722   104.042
    32.719   104.044
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.688   104.102
    32.719   104.044
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.638   104.168
    32.637   104.170
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.681   104.176
    32.637   104.170
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.794   104.077
    32.793   104.078
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.814   104.135
    32.793   104.078
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.864   104.122
    32.862   104.122
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.832   104.235
    32.862   104.122
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.591   104.175
    32.588   104.177
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.576   104.232
    32.588   104.177
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.749   104.105
    32.749   104.101
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.778   104.164
    32.749   104.101
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.461   104.104
    32.460   104.107
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.482   104.210
    32.460   104.107
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.358   104.142
    32.358   104.141
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.567   104.200
    32.358   104.141
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.472   104.062
    32.472   104.066
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.463   104.153
    32.472   104.066
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.825   104.068
    32.823   104.071
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.806   104.129
    32.823   104.071
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.917   104.096
    32.915   104.097
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.836   104.277
    32.915   104.097
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.647   104.151
    32.643   104.144
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.700   104.400
    32.643   104.144
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.829   104.146
    32.827   104.147
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.825   104.322
    32.827   104.147
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    34.098   104.401
    34.097   104.404
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    34.068   104.358
    34.097   104.404
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    33.406   104.782
    33.410   104.778
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    33.495   104.988
    33.410   104.778
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.618   104.158
    32.615   104.161
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.583   104.167
    32.615   104.161
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    33.064   104.925
    33.064   104.927
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    33.091   104.867
    33.064   104.927
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    34.031   104.307
    34.025   104.308
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    33.995   104.355
    34.025   104.308
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.450   104.196
    32.448   104.195
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.480   104.180
    32.448   104.195
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.933   103.989
    32.927   103.989
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.600   104.200
    32.927   103.989
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.978   104.026
    32.977   104.027
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.800   104.200
    32.977   104.027
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.731   104.091
    32.733   104.093
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.800   104.200
    32.733   104.093
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.580   103.439
    32.579   103.434
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.400   103.300
    32.579   103.434
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.873   104.092
    32.868   104.091
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    33.200   104.200
    32.868   104.091
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    33.339   104.406
    33.336   104.409
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    33.400   104.200
    33.336   104.409
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    33.388   103.243
    33.386   103.243
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    33.325   103.515
    33.386   103.243
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.390   104.212
    32.391   104.215
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.302   104.547
    32.391   104.215
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    34.256   103.298
    34.256   103.297
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    34.100   102.900
    34.256   103.297
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    34.262   103.315
    34.261   103.315
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    34.150   102.942
    34.261   103.315
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    34.305   103.311
    34.307   103.319
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    33.903   103.126
    34.307   103.319
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    33.594   103.691
    33.594   103.688
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    33.600   103.970
    33.594   103.688
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.819   104.096
    32.819   104.097
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.864   104.161
    32.819   104.097
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.820   104.106
    32.818   104.106
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.900   104.200
    32.818   104.106
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    34.084   105.097
    34.082   105.101
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    34.131   105.270
    34.082   105.101
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    34.289   103.303
    34.289   103.303
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    34.198   103.313
    34.289   103.303
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.451   104.118
    32.453   104.116
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.522   104.328
    32.453   104.116
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.949   103.879
    32.950   103.882
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.900   103.917
    32.950   103.882
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    33.110   104.846
    33.110   104.846
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    33.100   104.883
    33.110   104.846
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.228   103.720
    32.228   103.719
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.250   103.717
    32.228   103.719
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.968   103.964
    32.967   103.964
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.980   103.950
    32.967   103.964
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    33.731   104.795
    33.728   104.795
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    33.653   104.818
    33.728   104.795
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    33.430   103.825
    33.428   103.822
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    33.530   104.000
    33.428   103.822
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    33.039   104.516
    33.039   104.516
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    33.000   104.530
    33.039   104.516
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    33.010   104.494
    33.010   104.492
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    33.404   104.919
    33.010   104.492
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    33.137   103.848
    33.126   103.830
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    33.100   103.830
    33.126   103.830
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    33.119   103.802
    33.117   103.803
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    33.080   103.820
    33.117   103.803
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    33.337   103.796
    33.336   103.796
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    33.300   103.800
    33.336   103.796
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.596   104.197
    32.596   104.197
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.762   104.467
    32.596   104.197
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    33.890   102.809
    33.890   102.807
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    33.830   102.780
    33.890   102.807
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    33.122   103.825
    33.121   103.824
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    33.050   103.870
    33.121   103.824
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    33.116   103.819
    33.116   103.817
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    33.100   103.830
    33.116   103.817
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    33.709   103.277
    33.709   103.276
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    33.717   103.183
    33.709   103.276
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    33.020   103.866
    33.019   103.863
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    33.000   103.880
    33.019   103.863
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    33.131   103.648
    33.130   103.657
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    33.130   103.680
    33.130   103.657
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    33.308   104.655
    33.323   104.635
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    33.251   104.868
    33.323   104.635
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.504   104.034
    32.505   104.031
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.575   104.100
    32.505   104.031
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.972   103.981
    32.970   103.970
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.877   103.814
    32.970   103.970
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    33.395   102.779
    33.393   102.779
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    33.580   103.130
    33.393   102.779
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    33.123   103.836
    33.122   103.835
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    33.283   103.850
    33.122   103.835
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    34.149   102.835
    34.150   102.835
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    34.067   102.550
    34.150   102.835
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.602   103.326
    32.601   103.328
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.700   103.300
    32.601   103.328
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    33.244   103.846
    33.244   103.849
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    33.467   103.867
    33.244   103.849
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    33.246   103.831
    33.246   103.830
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    33.467   103.900
    33.246   103.830
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    33.799   103.990
    33.799   103.987
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    33.850   103.933
    33.799   103.987
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.985   102.643
    32.989   102.646
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    33.167   102.767
    32.989   102.646
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.273   104.432
    32.271   104.429
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.323   104.435
    32.271   104.429
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.241   104.536
    32.241   104.536
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.300   104.567
    32.241   104.536
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    33.864   103.888
    33.864   103.887
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    33.900   103.883
    33.864   103.887
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    33.611   104.830
    33.613   104.828
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    33.400   105.090
    33.613   104.828
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.647   102.513
    32.647   102.515
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.701   102.661
    32.647   102.515
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.620   102.502
    32.617   102.503
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.700   102.840
    32.617   102.503
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    33.311   103.466
    33.312   103.467
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    33.311   103.471
    33.312   103.467
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.925   104.528
    32.937   104.533
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.939   104.724
    32.937   104.533
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    34.322   103.323
    34.320   103.325
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    34.200   103.500
    34.320   103.325
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    33.217   103.152
    33.218   103.146
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    33.080   103.620
    33.218   103.146
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.746   102.815
    32.744   102.813
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.609   103.099
    32.744   102.813
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.638   103.031
    32.641   103.024
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.877   103.412
    32.641   103.024
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.241   103.706
    32.243   103.705
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.234   103.694
    32.243   103.705
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    33.664   102.791
    33.663   102.787
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    33.660   102.920
    33.663   102.787
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    34.303   103.274
    34.300   103.275
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    34.110   103.250
    34.300   103.275
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.280   104.662
    32.277   104.657
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.321   104.702
    32.277   104.657
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    33.588   104.509
    33.587   104.508
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    33.550   104.440
    33.587   104.508
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.786   104.172
    32.782   104.174
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.755   104.308
    32.782   104.174
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    33.317   103.434
    33.319   103.434
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    33.290   103.710
    33.319   103.434
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.627   102.569
    32.628   102.581
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.727   103.465
    32.628   102.581
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.238   103.760
    32.239   103.760
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.343   103.734
    32.239   103.760
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    33.132   104.918
    33.124   104.912
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    33.105   104.994
    33.124   104.912
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.656   104.140
    32.656   104.133
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.520   104.370
    32.656   104.133
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    33.396   104.704
    33.398   104.705
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    33.320   104.500
    33.398   104.705
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    33.099   104.944
    33.098   104.946
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.916   105.184
    33.098   104.946
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    33.369   104.752
    33.368   104.753
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    33.300   104.750
    33.368   104.753
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    33.108   104.569
    33.108   104.568
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    33.017   104.600
    33.108   104.568
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.723   104.793
    32.744   104.788
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.850   104.783
    32.744   104.788
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.950   104.215
    32.952   104.214
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.767   104.217
    32.952   104.214
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    33.091   104.894
    33.088   104.893
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    33.019   105.011
    33.088   104.893
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    33.068   102.640
    33.074   102.656
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    33.111   102.898
    33.074   102.656
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    34.295   104.849
    34.300   104.848
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    34.050   104.883
    34.300   104.848
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    33.667   104.908
    33.666   104.908
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    33.483   105.117
    33.666   104.908
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    33.834   104.909
    33.833   104.910
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    33.797   104.963
    33.833   104.910
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    34.077   104.340
    34.075   104.341
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    33.938   104.431
    34.075   104.341
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    33.929   104.365
    33.927   104.366
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    34.007   104.455
    33.927   104.366
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    33.062   104.791
    33.061   104.791
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    33.021   104.970
    33.061   104.791
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.204   104.864
    32.199   104.859
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.221   105.091
    32.199   104.859
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.324   105.170
    32.323   105.171
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.346   105.294
    32.323   105.171
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.251   104.893
    32.248   104.894
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.299   105.098
    32.248   104.894
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.301   104.880
    32.300   104.881
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.229   105.054
    32.300   104.881
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.566   105.296
    32.565   105.297
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.533   105.428
    32.565   105.297
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.293   104.975
    32.290   104.976
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.324   105.209
    32.290   104.976
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.529   105.168
    32.529   105.168
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.484   105.354
    32.529   105.168
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.420   104.994
    32.418   104.994
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.405   105.135
    32.418   104.994
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.487   105.057
    32.485   105.057
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.598   105.308
    32.485   105.057
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.351   105.031
    32.348   105.032
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.401   105.228
    32.348   105.032
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.268   104.889
    32.265   104.889
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.258   105.123
    32.265   104.889
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.509   105.214
    32.506   105.213
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.480   105.453
    32.506   105.213
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.304   104.975
    32.302   104.976
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.319   105.195
    32.302   104.976
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.457   105.103
    32.456   105.104
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.497   105.316
    32.456   105.104
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.262   104.604
    32.260   104.606
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.243   104.767
    32.260   104.606
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.456   105.077
    32.454   105.077
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.444   105.176
    32.454   105.077
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.252   104.761
    32.251   104.762
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.232   104.931
    32.251   104.762
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.213   104.828
    32.211   104.829
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.212   104.990
    32.211   104.829
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.425   105.234
    32.423   105.234
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.423   105.333
    32.423   105.234
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.235   104.857
    32.234   104.858
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.220   105.025
    32.234   104.858
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.400   105.046
    32.399   105.047
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.330   105.239
    32.399   105.047
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.347   104.848
    32.345   104.848
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.290   105.051
    32.345   104.848
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.547   105.292
    32.546   105.293
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.589   105.392
    32.546   105.293
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.509   105.091
    32.509   105.096
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.526   105.207
    32.509   105.096
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.640   105.319
    32.639   105.321
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.680   105.439
    32.639   105.321
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.673   105.311
    32.671   105.311
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.668   105.480
    32.671   105.311
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.326   104.936
    32.325   104.937
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.390   105.170
    32.325   104.937
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.292   105.014
    32.289   105.014
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.239   105.231
    32.289   105.014
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.322   104.909
    32.321   104.910
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.314   105.052
    32.321   104.910
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.533   105.313
    32.532   105.314
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.462   105.462
    32.532   105.314
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.481   104.984
    32.480   104.986
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.540   105.132
    32.480   104.986
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.497   105.068
    32.496   105.069
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.487   105.270
    32.496   105.069
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.293   104.804
    32.292   104.805
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.339   104.914
    32.292   104.805
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.409   105.085
    32.408   105.086
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.413   105.217
    32.408   105.086
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.374   105.025
    32.372   105.026
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.395   105.168
    32.372   105.026
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.473   105.147
    32.471   105.147
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.513   105.272
    32.471   105.147
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.513   105.274
    32.511   105.275
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.480   105.453
    32.511   105.275
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.288   104.974
    32.286   104.974
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.307   105.172
    32.286   104.974
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.399   104.988
    32.397   104.989
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.336   105.081
    32.397   104.989
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.214   104.792
    32.212   104.792
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.228   104.936
    32.212   104.792
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.531   105.089
    32.529   105.089
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.550   105.171
    32.529   105.089
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.301   104.784
    32.300   104.783
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.301   104.885
    32.300   104.783
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.507   105.133
    32.505   105.135
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.507   105.303
    32.505   105.135
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.204   104.388
    32.203   104.391
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.217   104.494
    32.203   104.391
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.516   105.329
    32.514   105.331
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.534   105.461
    32.514   105.331
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.510   105.190
    32.509   105.192
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.565   105.325
    32.509   105.192
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.458   105.062
    32.456   105.063
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.514   105.155
    32.456   105.063
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.961   104.827
    32.959   104.828
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.985   104.913
    32.959   104.828
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.499   105.074
    32.498   105.076
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.467   105.227
    32.498   105.076
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.213   104.446
    32.211   104.448
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.365   104.748
    32.211   104.448
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    32.293   105.411
    32.291   105.412
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    32.280   105.498
    32.291   105.412
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    33.202   103.712
    33.200   103.712
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    33.199   103.876
    33.200   103.712
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    33.155   103.727
    33.156   103.729
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    33.106   103.777
    33.156   103.729
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    33.233   103.747
    33.230   103.748
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    33.207   103.932
    33.230   103.748
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    33.156   103.562
    33.155   103.567
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    33.137   103.761
    33.155   103.567
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    33.625   102.864
    33.622   102.864
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    33.595   102.917
    33.622   102.864
END

# Confidence ellipses for relative location
gmt psxy -: -R $projection -SE -Wthick -O -K << END >> $psfile
    32.892   103.934    -5.348     2.782     4.313
    32.877   103.959    11.490     1.926     2.210
    32.899   103.963    27.720     2.257     4.396
    32.922   104.017    28.774     2.254     4.675
    32.898   103.974    27.898     1.815     3.617
    32.886   103.905    25.650     1.940     4.089
    32.862   103.928    16.428     3.399     5.636
    32.895   103.937    25.273     2.250     3.409
    32.911   103.957    22.130     2.106     3.428
    32.872   103.906    29.957     2.511     3.671
    32.998   103.945    27.003     2.644     4.665
    32.904   103.941    22.891     2.456     3.255
    32.882   103.892    10.451     2.775     4.337
    32.899   104.027    26.280     2.486     3.476
    32.939   104.031    12.839     2.318     3.213
    32.996   104.071    16.692     3.972     4.377
    33.027   103.930    10.854     2.106     3.123
    32.719   104.044   -54.803     1.512     1.835
    32.637   104.170   -13.387     2.941     4.576
    32.793   104.078     5.123     1.445     2.034
    32.862   104.122   -32.752     1.737     2.000
    32.588   104.177   -29.164     1.321     1.558
    32.749   104.101     5.056     2.250     4.225
    32.460   104.107   -44.467     1.302     1.511
    32.358   104.141    15.516     3.955     6.002
    32.472   104.066    -3.281     1.734     2.093
    32.823   104.071    15.656     1.819     2.045
    32.915   104.097     8.182     2.313     3.715
    32.643   104.144     0.103     5.080     6.072
    32.827   104.147     8.600     2.238     3.161
    34.097   104.404     8.377     4.338     9.138
    33.410   104.778   -41.193     3.604     7.142
    32.615   104.161    23.253     3.298     3.943
    33.064   104.927   -26.701     2.970     5.128
    34.025   104.308    49.477     3.015     3.908
    32.448   104.195    41.952     3.570     5.605
    32.927   103.989    29.643     4.613     6.174
    32.977   104.027    30.767     3.024     5.336
    32.733   104.093    51.773     7.395     9.473
    32.579   103.434    40.720     2.950     4.758
    32.868   104.091    46.665     4.340     6.389
    33.336   104.409    25.182     3.422     5.365
    33.386   103.243     9.592     4.134     5.263
    32.391   104.215    72.180     3.044     4.511
    34.256   103.297   -26.222     4.414     5.886
    34.261   103.315   -42.051     2.657     4.819
    34.307   103.319    -5.114     4.239     6.448
    33.594   103.688    -9.407     3.770     5.058
    32.819   104.097    35.685     2.479     2.921
    32.818   104.106   -15.511     3.219     3.990
    34.082   105.101   -21.077     1.896     1.996
    34.289   103.303   -44.049     4.691     6.930
    32.453   104.116    35.828     3.252     3.752
    32.950   103.882    25.073     4.512     6.548
    33.110   104.846    61.639     2.816     3.990
    32.228   103.719     5.557     1.829     3.692
    32.967   103.964     6.458     2.463     3.105
    33.728   104.795   -25.407     4.388     4.748
    33.428   103.822   -16.285     2.043     2.775
    33.039   104.516    51.877     3.168     3.564
    33.010   104.492    77.637     2.171     2.652
    33.126   103.830   -56.806     3.106     5.138
    33.117   103.803    17.710     1.851     2.398
    33.336   103.796    84.549     1.546     1.683
    32.596   104.197    51.487     2.290     3.105
    33.890   102.807   -16.146     2.215     4.098
    33.121   103.824   -29.576     2.380     2.676
    33.116   103.817    12.501     1.504     1.753
    33.709   103.276    58.895     1.635     1.921
    33.019   103.863    29.768     1.786     2.554
    33.130   103.657    45.653     2.168     2.832
    33.323   104.635    43.525     5.764     8.469
    32.505   104.031    53.609     3.569     5.974
    32.970   103.970    86.292     2.445     3.059
    33.393   102.779   -27.896     2.282     3.867
    33.122   103.835   -27.804     1.844     2.418
    34.150   102.835    86.615     3.771     4.389
    32.601   103.328   -85.296     2.169     3.910
    33.244   103.849    -8.818     1.916     2.481
    33.246   103.830   -20.230     2.040     2.406
    33.799   103.987   -18.256     1.579     3.092
    32.989   102.646    13.268     3.123     5.720
    32.271   104.429    27.944     2.903     4.339
    32.241   104.536    25.796     4.171     6.255
    33.864   103.887    -6.491     1.585     2.935
    33.613   104.828    51.131     2.490     3.113
    32.647   102.515   -41.787     2.515     3.171
    32.617   102.503   -16.072     3.619     5.060
    33.312   103.467   -39.456     1.784     2.341
    32.937   104.533    71.159     3.271     3.419
    34.320   103.325    43.481     3.531     5.794
    33.218   103.146   -12.385     2.611     3.463
    32.744   102.813   -22.021     2.433     3.377
    32.641   103.024   -79.730     3.173     4.890
    32.243   103.705    11.552     2.141     3.543
    33.663   102.787    -7.210     2.774     4.322
    34.300   103.275    48.599     3.744     5.958
    32.277   104.657    34.120     6.829    10.435
    33.587   104.508    40.694     4.109     6.770
    32.782   104.174   -41.588     2.234     2.405
    33.319   103.434    83.362     4.807     5.445
    32.628   102.581   -18.318     3.700     8.368
    32.239   103.760    55.306     3.209     3.911
    33.124   104.912   -77.975     2.112     2.290
    32.656   104.133    48.341     3.254     5.363
    33.398   104.705    68.540     2.923     3.549
    33.098   104.946    68.442     3.560     4.695
    33.368   104.753    60.976     2.639     2.908
    33.108   104.568    66.944     3.022     4.294
    32.744   104.788    75.360     3.607     5.560
    32.952   104.214    71.201     2.578     3.799
    33.088   104.893    42.461     1.854     3.369
    33.074   102.656   -44.231     4.838     5.908
    34.300   104.848    80.689     4.073     8.882
    33.666   104.908   -79.944     4.494     5.152
    33.833   104.910   -70.080     2.581     2.898
    34.075   104.341   -44.616     4.075     6.099
    33.927   104.366   -31.457     4.492     6.742
    33.061   104.791   -32.842     2.824     3.552
    32.199   104.859   -45.069     2.781     4.056
    32.323   105.171   -45.123     6.379     8.072
    32.248   104.894   -38.315     4.925     8.453
    32.300   104.881   -35.239     3.206     6.453
    32.565   105.297   -44.494     4.628     7.423
    32.290   104.976   -36.118     2.551     5.395
    32.529   105.168    54.875     0.646     6.057
    32.418   104.994   -41.866     3.314     5.147
    32.485   105.057   -39.702     4.397     4.839
    32.348   105.032   -41.788     2.397     3.839
    32.265   104.889   -34.329     2.226     3.963
    32.506   105.213   -42.585     3.981     6.789
    32.302   104.976   -40.612     3.469     5.073
    32.456   105.104   -45.068     4.587     6.313
    32.260   104.606   -43.828     2.066     3.069
    32.454   105.077   -71.234     4.540     5.721
    32.251   104.762   -31.681     6.423    10.716
    32.211   104.829   -55.034     1.143     1.496
    32.423   105.234   -30.245     2.702     3.687
    32.234   104.858   -50.595     1.562     2.160
    32.399   105.047   -45.750     4.685     5.520
    32.345   104.848    -0.142     4.684     6.789
    32.546   105.293   -61.575     1.279     1.675
    32.509   105.096   -61.939     3.221     4.457
    32.639   105.321   -59.866     2.279     2.605
    32.671   105.311   -85.445     2.672     3.172
    32.325   104.937   -65.322     4.794     6.175
    32.289   105.014   -35.313     2.932     4.245
    32.321   104.910   -69.153     1.553     1.992
    32.532   105.314   -35.794     3.789     7.389
    32.480   104.986   -34.758     5.772     7.765
    32.496   105.069   -49.494     2.208     3.389
    32.292   104.805   -58.220     2.854     3.516
    32.408   105.086   -40.978     2.571     3.512
    32.372   105.026   -37.376     2.326     4.892
    32.471   105.147   -35.844     1.902     3.570
    32.511   105.275   -52.099     1.291     1.708
    32.286   104.974   -44.568     2.090     3.300
    32.397   104.989   -46.396     1.394     1.679
    32.212   104.792   -40.349     3.740     4.370
    32.529   105.089   -18.332     2.199     2.891
    32.300   104.783    -5.685     3.208     3.476
    32.505   105.135   -35.468     6.773     8.941
    32.203   104.391   -62.137     4.664     5.809
    32.514   105.331   -21.569     2.723     4.112
    32.509   105.192   -53.169     1.360     1.647
    32.456   105.063   -37.056     2.575     3.186
    32.959   104.828   -17.883     2.686     3.755
    32.498   105.076   -49.391     2.210     2.986
    32.211   104.448   -67.740     3.663     3.967
    32.291   105.412   -68.886     2.614     2.909
    33.200   103.712   -41.636     1.524     1.823
    33.156   103.729   -82.137     2.518     3.740
    33.230   103.748     4.466     1.826     2.292
    33.155   103.567   -48.638     2.733     4.118
    33.622   102.864    -3.582     2.279     3.161
END

# Hypocentroid confidence ellipse
gmt psxy -: -R $projection -SE -Wthick,blue -O -K << END >> $psfile
    32.153   102.466    51.641     1.893     1.951
END
gmt pstext -: -R $projection -F+f6p,Helvetica,blue+a0.+jBL -O -K << END >> $psfile
    32.153   102.488   Hypocentroid
END

# Circle of radius 5 km for reference
gmt psxy -: -R $projection -SE -Wthick,red -O -K << END >> $psfile
    32.153   102.466     0.000    10.000    10.000
END
gmt psxy -: -R $projection -Sx -Wthinnest,blue -O -K << END >> $psfile
    32.153   102.466     0.070
END
gmt pstext -: -R $projection -F+f6p,Helvetica-Bold,red+a0.+jBC -Gwhite -O << END >> $psfile
    32.108   102.466   5 km
END
